@@ -7,6 +7,18 @@ import (
 	"github.com/cybertec-postgresql/vip-manager/iphlpapi"
 )
 
+func sendPacketWindows(iface net.Interface, packetData []byte) error {
+	// Open a raw socket using Winsock
+	conn, err := net.Dial("ip4:ethernet", iface.HardwareAddr.String())
+	if err != nil {
+		return err
+	}
+	defer conn.Close()
+	// Send the packet
+	_, err = conn.Write(packetData)
+	return err
+}
+
 // configureAddress assigns virtual IP address
 func (c *BasicConfigurer) configureAddress() bool {
 	log.Infof("Configuring address %s on %s", c.getCIDR(), c.Iface.Name)
@@ -25,10 +37,14 @@ func (c *BasicConfigurer) configureAddress() bool {
 		log.Error("Failed to add address: ", err)
 		return false
 	}
-	// For now it is save to say that also working even if a
-	// gratuitous arp message could not be send but logging an
-	// errror should be enough.
-	//_ = c.ARPSendGratuitous()
+
+	if buff, err := c.createGratuitousARP(); err != nil {
+		log.Warn("Failed to compose gratuitous ARP request: ", err)
+	} else {
+		if err := sendPacketWindows(c.Iface, buff); err != nil {
+			log.Warn("Failed to send gratuitous ARP request: ", err)
+		}
+	}
 	return true
 }
 
